@@ -6,6 +6,7 @@
 *   ??/??/??   PRP   Original.
 *   01/20/05   DGP   Changes for correct channel operation.
 *   01/28/05   DGP   Revamped channel and tape controls.
+*   02/14/05   DGP   Clean up inst. trace display.
 *   
 ***********************************************************************/
 
@@ -33,7 +34,7 @@ lights()
 
    if (!panelmode) return;
 
-   screenposition(1,1);
+   screenposition(TOPLINE,1);
    clearline();
    printf("IBM %d Simulator %s\n", cpumode, VERSION); 
 #if 0
@@ -79,7 +80,6 @@ lights()
 	 iochk?   "CHECK"         : "     ",
 	 machchk?" CHECK "       : "       ");
 
-   clearline();
    if (!automatic)
       status = "MANUAL      ";
    else if (stop)
@@ -88,6 +88,7 @@ lights()
       status = "AUTOMATIC   ";
    else
       status = "READY       ";
+   clearline();
    printf(
      "%s  SSW %o%o%o%o%o%o  SL %o%o%o%o  %s  RUN %d+%03o  KEYS %c%02o%010lo \n",
       status,
@@ -114,24 +115,25 @@ lights()
 
    clearline();
    if (cpumode == 7094)
-
       printf("X1 %05o  X2 %05o  X3 %05o  X4 %05o  X5 %05o  X6 %05o  X7 %05o \n",
-        xr[1], xr[2], xr[3], xr[4], xr[5], xr[6], xr[7]);
+	   xr[1], xr[2], xr[3], xr[4], xr[5], xr[6], xr[7]);
    else
       printf("X1 %05o  X2 %05o  X4 %05o  \n",
-        xr[1], xr[2], xr[4]);
+	   xr[1], xr[2], xr[4]);
 
+   clearline();
    printf("SR %c %02o%010lo     ENB 00%010lo     IND     %01o\n",
-      (srh & SIGN)? '-' : '+',
-      ((srh & HMSK) << 2) | (short)(srl >> 30),
-      srl & 07777777777,
-      ctrap_enb, ctrap_ind);
+	 (srh & SIGN)? '-' : '+',
+	 ((srh & HMSK) << 2) | (short)(srl >> 30),
+	 srl & 07777777777,
+	 ctrap_enb, ctrap_ind);
+   clearline();
    printf("AC %c%03o%010lo      SI %02o%010lo\n",
-      (ach & SIGN)? '-' : '+',
-      ((ach & 037) << 2) | (short)(acl >> 30),
-      acl & 07777777777,
-      ((sih & 017) << 2) | (short)(sil >> 30),
-      sil & 07777777777);
+	 (ach & SIGN)? '-' : '+',
+	 ((ach & 037) << 2) | (short)(acl >> 30),
+	 acl & 07777777777,
+	 ((sih & 017) << 2) | (short)(sil >> 30),
+	 sil & 07777777777);
 
    clearline();
    printf("MQ %c %02o%010lo",
@@ -141,14 +143,13 @@ lights()
 
    if (addrstop)
       printf("     ADDRESS STOP   %05o\n", stopic);
-   else
-      printf("                         \n");
 
+   screenposition (CHANNELLINE,1);
    clearline();
-   screenposition (10,1);
    for (c1 = 0; c1 < NUMCHAN; c1 += 4)
    {
       printf("\n");
+      clearline();
       for (c2 = c1; c2 < c1 + 4 && c2 < NUMCHAN; c2++)
       {
          int dev;
@@ -183,22 +184,29 @@ lights()
          printf("  ");
       }
       printf("\n");
+      clearline();
       for (c2 = c1; c2 < c1 + 4 && c2 < NUMCHAN; c2++)
+      {
          printf("OP %o%c UN %03o%c ",
                 channel[c2].cop & 007,
                 (channel[c2].cop & 010)? 'N' : ' ',
                 channel[c2].cunit,
                 " RWBFM"[channel[c2].csel]);
+      }
       printf("\n");
+      clearline();
       for (c2 = c1; c2 < c1 + 4 && c2 < NUMCHAN; c2++)
          printf("AR     %05o%c ", channel[c2].car, channel[c2].ctrp? 'T' : ' ');
       printf("\n");
+      clearline();
       for (c2 = c1; c2 < c1 + 4 && c2 < NUMCHAN; c2++)
          printf("WR     %05o%c ", channel[c2].cwr, channel[c2].ceof? 'E' : ' ');
       printf("\n");
+      clearline();
       for (c2 = c1; c2 < c1 + 4 && c2 < NUMCHAN; c2++)
          printf("LR     %05o%c ", channel[c2].clr, channel[c2].cchk? 'C' : ' ');
       printf("\n");
+      clearline();
       for (c2 = c1; c2 < c1 + 4 && c2 < NUMCHAN; c2++)
          printf("%02o%010lo  ",
 	       ((channel[c2].cdrh & SIGN) >> 2) |
@@ -208,21 +216,21 @@ lights()
       printf("\n");
       clearline();
    }
-   screenposition(17,1);
+   screenposition(OUTPUTLINE,1);
 }
 
 void
 pview()
 {
-   uint32 i;
+   int i;
 
    if (!panelmode) 
    {
-      printf ("%s\n", prtview[prtviewlen]);
+      printf ("%s\n", prtview[prtviewlen-1]);
       return;
    }
    
-   screenposition (17,1);
+   screenposition (OUTPUTLINE,1);
    printf("\n");
    clearline();
 
@@ -238,7 +246,7 @@ help()
 {
 
    if (panelmode)
-      screenposition (17,1);
+      screenposition (OUTPUTLINE,1);
 
    printf("\n\
   h - help            r - reset       clear - clear         sw# - toggle SSW#\n\
@@ -256,14 +264,15 @@ trace()
    int32 i, j, tp;
 
    if (panelmode)
-      screenposition (17,1);
+      screenposition (OUTPUTLINE,1);
 
    printf("\n");
-   printf(
-      "Instruction trace:                                                 \n");
+   if (panelmode) clearline();
+   printf("Instruction trace:  \n");
    tp = itrc_idx;
    for (i = 0; i < 4; i++)
    {
+      if (panelmode) clearline();
       printf("  ");
       for (j = 0; j < 8; j++)
       {
@@ -286,16 +295,19 @@ void
 long_trace()
 {
    int i, j, tp;
+   int line;
 
    if (panelmode)
-      screenposition (17,1);
+      screenposition (OUTPUTLINE,1);
 
    printf("\n");
-   printf(
-      "Instruction trace:                                                 \n");
+   if (panelmode) clearline();
+   printf( "Instruction trace: \n");
    tp = itrc_idx;
+   line = 1;
    for (i = 0; i < 16; i++)
    {
+      if (panelmode) clearline();
       for (j = 0; j < 2; j++)
       {
          if (j > 0)
@@ -313,6 +325,17 @@ long_trace()
          if (tp == 32)
             tp = 0;
       }
-      printf("        \n");
+      printf("\n");
+      line++;
+      if (panelmode && line >= prtviewlen)
+      {
+	 printf ("press enter to continue:");
+	 fgetc (stdin);
+	 screenposition (OUTPUTLINE,1);
+	 printf("\n");
+	 clearline();
+	 printf( "Instruction trace: \n");
+	 line = 1;
+      }
    }
 }
