@@ -13,6 +13,8 @@
 #define EXTERN
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include "sysdef.h"
 #include "regs.h"
@@ -469,10 +471,16 @@ main (int argc, char **argv)
    if (panelmode)
    {
       clearscreen();
-      screenposition (1,1);
+      screenposition (TOPLINE,1);
    }
    else
+   {
       printf("IBM %d Simulator %s\n", cpumode, VERSION); 
+   }
+
+   /*
+   ** If specified, Open command file.
+   */
 
    if (usecmdfile)
    {
@@ -484,10 +492,11 @@ main (int argc, char **argv)
 	 exit (1);
       }
    }
-   /*kyh = (char)SIGN;*/
-   /*kyl = 0100037;*/
-   kyh = 00; /* TRA   3 */
-   kyl = 002000000003 ;
+
+   kyh = (char)SIGN;
+   kyl = 0100037;
+   /*kyh = 00; *//* TRA   3 */
+   /*kyl = 002000000003 ;*/
    automatic = 1;
    s709();
    iofin();
